/*
 *  Copyright (C) 2005-2021 Team Kodi (https://kodi.tv)
 *
 *  SPDX-License-Identifier: GPL-2.0-or-later
 *  See LICENSE.md for more information.
 */

float4 main(float4 pos: SV_POSITION, float4 col : COLOR) : SV_TARGET
{
  return col;
}